answers = {
    "en": [
        "Yes, definitely!",
        "It is certain.",
        "Without a doubt.",
        "You may rely on it.",
        "As I see it, yes.",
        "Most likely.",
        "Outlook good.",
        "Signs point to yes.",
        "Yes.",
        "Better not tell you now.",
        "Ask again later.",
        "Cannot predict now.",
        "Don’t count on it.",
        "My sources say no.",
        "Outlook not so good.",
        "Very doubtful.",
        "Concentrate and ask again.",
        "Reply hazy, try again.",
        "It is decidedly so.",
        "All signs point to yes!"
    ],
    "fr": [
        "Oui, absolument!",
        "C'est certain.",
        "Sans aucun doute.",
        "Vous pouvez compter dessus.",
        "D'après moi, oui.",
        "Très probable.",
        "Les perspectives sont bonnes.",
        "Les signes indiquent que oui.",
        "Oui.",
        "Mieux vaut ne pas te le dire maintenant.",
        "Demande encore plus tard.",
        "Impossible de prédire maintenant.",
        "Ne compte pas là-dessus.",
        "Mes sources disent non.",
        "Les perspectives ne sont pas très bonnes.",
        "Très douteux.",
        "Concentre-toi et demande encore.",
        "Réponse floue, essaie encore.",
        "C'est décidément ainsi.",
        "Tous les signes indiquent que oui!"
    ],
    "es": [
        "¡Sí, definitivamente!",
        "Es cierto.",
        "Sin duda.",
        "Puedes confiar en ello.",
        "Según veo, sí.",
        "Muy probable.",
        "Las perspectivas son buenas.",
        "Las señales apuntan a que sí.",
        "Sí.",
        "Mejor no decirte ahora.",
        "Pregunta de nuevo más tarde.",
        "No puedo predecir ahora.",
        "No cuentes con ello.",
        "Mis fuentes dicen que no.",
        "Las perspectivas no son muy buenas.",
        "Muy dudoso.",
        "Concéntrate y pregunta de nuevo.",
        "Respuesta confusa, intenta otra vez.",
        "Es decididamente así.",
        "¡Todos los signos apuntan a que sí!"
    ]
}
