questions = {
    "en": [
        "Will I have a good day today?",
        "Should I go for that job interview?",
        "Is it a good time to start a new project?",
        "Will I find true love soon?",
        "Should I ask them out?",
        "Will I ace my test tomorrow?",
        "Is my crush thinking about me?",
        "Is today my lucky day?",
        "Should I take a vacation?",
        "Will I get a promotion this year?",
        "Is it time to try a new hobby?",
        "Will I become wealthy?",
        "Should I order takeout tonight?",
        "Is it a good idea to start my own business?",
        "Will my team win the game?",
        "Is now the right time to make a big change?",
        "Will I be successful in my career?",
        "Should I watch that new movie?",
        "Will I achieve my goals this year?",
        "Should I trust that person?"
    ],
    "fr": [
        "Vais-je passer une bonne journée aujourd'hui?",
        "Devrais-je passer cet entretien d'embauche?",
        "Est-ce un bon moment pour commencer un nouveau projet?",
        "Vais-je trouver le grand amour bientôt?",
        "Devrais-je lui proposer de sortir?",
        "Vais-je réussir mon examen demain?",
        "Mon coup de cœur pense-t-il à moi?",
        "Est-ce mon jour de chance aujourd'hui?",
        "Devrais-je prendre des vacances?",
        "Vais-je obtenir une promotion cette année?",
        "Est-il temps d'essayer un nouveau passe-temps?",
        "Vais-je devenir riche?",
        "Devrais-je commander à emporter ce soir?",
        "Est-ce une bonne idée de créer ma propre entreprise?",
        "Mon équipe va-t-elle gagner le match?",
        "Est-ce le bon moment pour faire un grand changement?",
        "Vais-je réussir dans ma carrière?",
        "Devrais-je regarder ce nouveau film?",
        "Vais-je atteindre mes objectifs cette année?",
        "Devrais-je faire confiance à cette personne?"
    ],
    "es": [
        "¿Tendré un buen día hoy?",
        "¿Debería ir a esa entrevista de trabajo?",
        "¿Es un buen momento para comenzar un nuevo proyecto?",
        "¿Encontraré el verdadero amor pronto?",
        "¿Debería invitarles a salir?",
        "¿Aprobaré mi examen mañana?",
        "¿Está mi crush pensando en mí?",
        "¿Es hoy mi día de suerte?",
        "¿Debería tomar unas vacaciones?",
        "¿Recibiré una promoción este año?",
        "¿Es momento de probar un nuevo pasatiempo?",
        "¿Me volveré rico?",
        "¿Debería pedir comida para llevar esta noche?",
        "¿Es una buena idea iniciar mi propio negocio?",
        "¿Ganará mi equipo el partido?",
        "¿Es ahora el momento adecuado para hacer un gran cambio?",
        "¿Tendré éxito en mi carrera?",
        "¿Debería ver esa nueva película?",
        "¿Lograré mis objetivos este año?",
        "¿Debería confiar en esa persona?"
    ]
}